==> apache-cloudstack-4.20.2.0-src.tar.bz2: apache-cloudstack-4.20.2.0-src/engine/schema/src/main/java/com/cloud/vm/snapshot/dao/VMSnapshotDao.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package com.cloud.vm.snapshot.dao;

import java.util.List;

import com.cloud.utils.db.GenericDao;
import com.cloud.utils.fsm.StateDao;
import com.cloud.vm.snapshot.VMSnapshot;
import com.cloud.vm.snapshot.VMSnapshotVO;

public interface VMSnapshotDao extends GenericDao<VMSnapshotVO, Long>, StateDao<VMSnapshot.State, VMSnapshot.Event, VMSnapshot> {

    List<VMSnapshotVO> findByVm(Long vmId);

    List<VMSnapshotVO> listExpungingSnapshot();

    List<VMSnapshotVO> listByInstanceId(Long vmId, VMSnapshot.State... status);

    VMSnapshotVO findCurrentSnapshotByVmId(Long vmId);

    List<VMSnapshotVO> listByParent(Long vmSnapshotId);

    VMSnapshotVO findByName(Long vmId, String name);

    List<VMSnapshotVO> listByAccountId(Long accountId);

    List<VMSnapshotVO> searchByVms(List<Long> vmIds);

    List<VMSnapshotVO> searchRemovedByVms(List<Long> vmIds, Long batchSize);
}

==> apache-cloudstack-4.21.0.0-src.tar.bz2: apache-cloudstack-4.21.0.0-src/engine/schema/src/main/java/com/cloud/vm/snapshot/dao/VMSnapshotDao.java <==
// Licensed to the Apache Software Foundation (ASF) under one
// or more contributor license agreements.  See the NOTICE file
// distributed with this work for additional information
// regarding copyright ownership.  The ASF licenses this file
// to you under the Apache License, Version 2.0 (the
// "License"); you may not use this file except in compliance
// with the License.  You may obtain a copy of the License at
//
//   http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing,
// software distributed under the License is distributed on an
// "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
// KIND, either express or implied.  See the License for the
// specific language governing permissions and limitations
// under the License.
package com.cloud.vm.snapshot.dao;

import java.util.List;

import com.cloud.utils.db.GenericDao;
import com.cloud.utils.fsm.StateDao;
import com.cloud.vm.snapshot.VMSnapshot;
import com.cloud.vm.snapshot.VMSnapshotVO;

public interface VMSnapshotDao extends GenericDao<VMSnapshotVO, Long>, StateDao<VMSnapshot.State, VMSnapshot.Event, VMSnapshot> {

    List<VMSnapshotVO> findByVm(Long vmId);

    List<VMSnapshotVO> findByVmAndByType(Long vmId, VMSnapshot.Type type);

    List<VMSnapshotVO> listExpungingSnapshot();

    List<VMSnapshotVO> listByInstanceId(Long vmId, VMSnapshot.State... status);

    VMSnapshotVO findCurrentSnapshotByVmId(Long vmId);

    List<VMSnapshotVO> listByParent(Long vmSnapshotId);

    List<VMSnapshotVO> listByParentAndStateIn(Long vmSnapshotId, VMSnapshot.State... states);

    VMSnapshotVO findByName(Long vmId, String name);

    List<VMSnapshotVO> listByAccountId(Long accountId);
    List<VMSnapshotVO> searchByVms(List<Long> vmIds);
    List<VMSnapshotVO> searchRemovedByVms(List<Long> vmIds, Long batchSize);
}
